@@ -27,7 +27,7 @@ from xpander_sdk.models.shared import LLMModelT, OutputFormat, XPanderSharedMode
 from xpander_sdk.models.user import User
 from xpander_sdk.modules.agents.models.agent import (
     AgentAccessScope,
-    AgentDeploymentProvider,
+    AgentDeploymentType,
     AgentGraphItem,
     AgentGraphItemType,
     AgentInstructions,
@@ -133,7 +133,6 @@ class Agent(XPanderSharedModel):
             unique_name: str
             origin_template: Optional[str]
             environment_id: str
-            deployment_provider: Optional[AgentDeploymentProvider]
             tools: Optional[ToolsRepository]
             icon: Optional[str]
             source_nodes: Optional[List[AgentSourceNode]]
@@ -145,6 +144,7 @@ class Agent(XPanderSharedModel):
             knowledge_bases: Optional[List[AgentKnowledgeBase]]
             version: Optional[int]
             created_by: Optional[str]
+            using_nemo: Optional[bool]
             model_provider: str
             model_name: str
             webhook_url: Optional[str]
@@ -168,11 +168,9 @@ class Agent(XPanderSharedModel):
     unique_name: str
     origin_template: Optional[str] = None
     environment_id: str = None
-    deployment_provider: Optional[AgentDeploymentProvider] = (
-        AgentDeploymentProvider.XPander
-    )
     tools: Optional[ToolsRepository] = None
     icon: Optional[str] = "🚀"
+    deployment_type: Optional[AgentDeploymentType] = AgentDeploymentType.Serverless
     source_nodes: Optional[List[AgentSourceNode]] = []
     access_scope: Optional[AgentAccessScope] = AgentAccessScope.Organizational
     instructions: Optional[AgentInstructions] = AgentInstructions(
@@ -184,6 +182,7 @@ class Agent(XPanderSharedModel):
     knowledge_bases: Optional[List[AgentKnowledgeBase]] = []
     version: Optional[int] = 1
     created_by: Optional[str] = None
+    using_nemo: Optional[bool] = False
     model_provider: str
     model_name: str
     webhook_url: Optional[str] = None
@@ -389,6 +388,9 @@ class Agent(XPanderSharedModel):
         events_streaming: Optional[bool] = False,
         additional_context: Optional[str] = None,
         expected_output: Optional[str] = None,
+        mcp_servers: Optional[List[MCPServerDetails]] = [],
+        triggering_agent_id: Optional[str] = None,
+        title: Optional[str] = None,
     ) -> Task:
         """
         Asynchronously create a new task and link it to this agent.
@@ -408,6 +410,9 @@ class Agent(XPanderSharedModel):
             events_streaming (Optional[bool]): Flag idicating for events are required for this task.
             additional_context (Optional[str]): Additional context to be passed to the agent.
             expected_output (Optional[str]): Expected output of the execution.
+            mcp_servers (Optional[List[MCPServerDetails]]): Optional list of mcp servers to use.
+            triggering_agent_id (Optional[str]): Optional triggering agent id.
+        title (Optional[str]): Optional task title.
 
         Returns:
             Task: Created Task object linked to this agent.
@@ -436,7 +441,10 @@ class Agent(XPanderSharedModel):
                     "run_locally": run_locally,
                     "events_streaming": events_streaming,
                     "additional_context": additional_context,
-                    "expected_output": expected_output
+                    "expected_output": expected_output,
+                    "mcp_servers": [server.model_dump() for server in mcp_servers],
+                    "triggering_agent_id": triggering_agent_id,
+                    "title": title,
                 },
             )
             return Task(**created_task, configuration=self.configuration)
@@ -558,12 +566,12 @@ class Agent(XPanderSharedModel):
         except Exception as e:
             logger.warning(f"Failed to sync local tools - {str(e)}")
 
-    async def aget_storage(self):
+    async def aget_db(self):
         """
-        Asynchronously retrieve the storage backend for this agent.
+        Asynchronously retrieve the db for this agent.
 
         Returns:
-            PostgresStorage: Initialized storage backend for agent sessions.
+            PostgresDb: Initialized db (Agno PG) for agent sessions.
 
         Raises:
             NotImplementedError: If the framework does not support storage.
@@ -579,104 +587,37 @@ class Agent(XPanderSharedModel):
             raise LookupError("Session storage is not enabled for this agent.")
 
         try:
-            from agno.storage.postgres import PostgresStorage
+            from agno.db.postgres import PostgresDb
         except ImportError as e:
             raise ImportError(
-                "The 'agno' extras must be installed to use this storage backend. "
+                "The 'agno' extras must be installed to use this db. "
                 "Run `pip install xpander-sdk[agno]`."
             ) from e
 
         connection_string = await self.aget_connection_string()
         if not connection_string or not connection_string.connection_uri.uri:
             raise ValueError(
-                "Invalid connection string provided for Agno storage backend."
+                "Invalid connection string provided for Agno db."
             )
 
         schema = get_db_schema_name(agent_id=self.id)
 
-        return PostgresStorage(
-            table_name="team_sessions" if self.agno_settings.coordinate_mode else "agent_sessions",
-            schema=schema,
+        return PostgresDb(
+            db_schema=schema,
             db_url=connection_string.connection_uri.uri,
-            auto_upgrade_schema=True,
-            mode="team" if self.agno_settings.coordinate_mode else "agent"
         )
 
-    def get_storage(self) -> Any:
+    def get_db(self) -> Any:
         """
-        Synchronously retrieve the storage backend for this agent.
+        Synchronously retrieve the db for this agent.
 
         Returns:
-            Any: Initialized storage backend for agent sessions.
+            Any: Initialized db for agent sessions.
 
         Example:
-            >>> storage = agent.get_storage()
+            >>> db = agent.get_db()
         """
-        return run_sync(self.aget_storage())
-
-    async def aget_memory_handler(self, model: LLMModelT):
-        """
-        Asynchronously retrieve the memory handler backend for user memories.
-
-        Args:
-            model (LLMModelT): Language model type to associate with memory handler.
-
-        Returns:
-            Memory: Initialized memory handler for user memories associated with the provided model.
-
-        Raises:
-            NotImplementedError: If the framework does not support user memories.
-            ImportError: If required dependencies are missing.
-            ValueError: If the connection string for memory storage is invalid.
-        """
-        if self.framework != Framework.Agno:
-            raise NotImplementedError(
-                f"Memory for framework '{self.framework}' is not supported."
-            )
-
-        if not self.agno_settings.user_memories:
-            raise LookupError("User memories not enabled for this agent.")
-
-        try:
-            from agno.memory.v2.memory import Memory
-            from agno.memory.v2.db.postgres import PostgresMemoryDb
-        except ImportError as e:
-            raise ImportError(
-                "The 'agno' extras must be installed to use this users memory backend. "
-                "Run `pip install xpander-sdk[agno]`."
-            ) from e
-
-        connection_string = await self.aget_connection_string()
-        if not connection_string or not connection_string.connection_uri.uri:
-            raise ValueError(
-                "Invalid connection string provided for Agno storage backend."
-            )
-
-        schema = get_db_schema_name(agent_id=self.id)
-
-        return Memory(
-            model=model,
-            db=PostgresMemoryDb(
-                table_name="user_memories",
-                schema=schema,
-                db_url=connection_string.connection_uri.uri,
-            ),
-        )
-
-    def get_memory_handler(self, model: LLMModelT) -> Any:
-        """
-        Synchronously retrieve the memory handler backend for user memories.
-
-        Args:
-            model (LLMModelT): Language model type to associate with memory handler.
-
-        Returns:
-            Any: Initialized memory handler for user memories.
-
-        Example:
-            >>> memory_handler = agent.get_memory_handler(model=my_model)
-        """
-        return run_sync(self.aget_memory_handler(model=model))
+        return run_sync(self.aget_db())
 
     @computed_field
     @property
@@ -688,6 +629,17 @@ class Agent(XPanderSharedModel):
             bool: True if one or more knowledge bases are linked, otherwise False.
         """
         return len(self.knowledge_bases) != 0
+    
+    @computed_field
+    @property
+    def is_a_team(self) -> bool:
+        """
+        Check if this agent run in Team mode
+
+        Returns:
+            bool: True if has sub agents, otherwise False.
+        """
+        return self.graph.sub_agents and len(self.graph.sub_agents) != 0
 
     def knowledge_bases_retriever(
         self,
@@ -754,7 +706,7 @@ class Agent(XPanderSharedModel):
         Asynchronously retrieve all user sessions associated with this agent.
 
         This method loads all saved session records linked to the specified user ID from
-        the agent's storage backend. It is only supported for agents using the Agno framework
+        the agent's db. It is only supported for agents using the Agno framework
         with session storage enabled.
 
         Args:
@@ -772,8 +724,9 @@ class Agent(XPanderSharedModel):
         Example:
             >>> sessions = await agent.aget_user_sessions(user_id="user_123")
         """
-        storage = await self.aget_storage()
-        sessions = await asyncio.to_thread(storage.get_recent_sessions, user_id=user_id, limit=50)
+        db = await self.aget_db()
+        from agno.db import SessionType
+        sessions = await asyncio.to_thread(db.get_sessions, user_id=user_id, limit=50, session_type = SessionType.TEAM if self.is_a_team else SessionType.AGENT)
         return sessions
     
     def get_user_sessions(self, user_id: str):
@@ -781,7 +734,7 @@ class Agent(XPanderSharedModel):
         Synchronously retrieve all user sessions associated with this agent.
 
         This method wraps the asynchronous `aget_user_sessions` method and returns the result
-        in a synchronous context. It loads session data for a given user ID from the agent's storage backend.
+        in a synchronous context. It loads session data for a given user ID from the agent's db.
 
         Args:
             user_id (str): Identifier of the user whose sessions are to be retrieved.
@@ -798,7 +751,7 @@ class Agent(XPanderSharedModel):
         """
         Asynchronously retrieve a single session by its session ID.
 
-        This method accesses the agent's storage backend and loads the session record
+        This method accesses the agent's db and loads the session record
         corresponding to the given session ID. It is only supported for agents using
         the Agno framework with session storage enabled.
 
@@ -817,8 +770,9 @@ class Agent(XPanderSharedModel):
         Example:
             >>> session = await agent.aget_session(session_id="sess_456")
         """
-        storage = await self.aget_storage()
-        session = await asyncio.to_thread(storage.read, session_id=session_id)
+        db = await self.aget_db()
+        from agno.db import SessionType
+        session = await asyncio.to_thread(db.get_session, session_id=session_id, session_type = SessionType.TEAM if self.is_a_team else SessionType.AGENT)
         return session
 
     def get_session(self, session_id: str):
@@ -827,7 +781,7 @@ class Agent(XPanderSharedModel):
 
         This method wraps the asynchronous `aget_session` and returns the result
         in a synchronous context. It retrieves the session record from the agent's
-        storage backend using the given session ID.
+        db using the given session ID.
 
         Args:
             session_id (str): Unique identifier of the session to retrieve.
@@ -844,7 +798,7 @@ class Agent(XPanderSharedModel):
         """
         Asynchronously delete a session by its session ID.
 
-        This method removes a specific session record from the agent's storage backend
+        This method removes a specific session record from the agent's db
         based on the provided session ID. It is only supported for agents using the
         Agno framework with session storage enabled.
 
@@ -860,15 +814,15 @@ class Agent(XPanderSharedModel):
         Example:
             >>> await agent.adelete_session(session_id="sess_456")
         """
-        storage = await self.aget_storage()
-        await asyncio.to_thread(storage.delete_session, session_id=session_id)
+        db = await self.aget_db()
+        await asyncio.to_thread(db.delete_session, session_id=session_id)
     
     def delete_session(self, session_id: str):
         """
         Synchronously delete a session by its session ID.
 
         This method wraps the asynchronous `adelete_session` and removes the session
-        record from the agent's storage backend in a synchronous context.
+        record from the agent's db in a synchronous context.
 
         Args:
             session_id (str): Unique identifier of the session to delete.
